@@ -18,15 +18,26 @@
 #ifndef LOGSTALGIA_H
 #define LOGSTALGIA_H
 
-#include "core/sdlapp.h"
-#include "core/fontpack.h"
-#include "core/stringhash.h"
+#define LOGSTALGIA_VERSION "1.0.0"
 
+#ifdef _WIN32
+#include "windows.h"
+#endif
+
+#include "core/display.h"
+#include "core/fxfont.h"
+#include "core/stringhash.h"
+#include "core/seeklog.h"
+
+#include "apache.h"
+#include "custom.h"
 #include "logentry.h"
 #include "paddle.h"
 #include "requestball.h"
 #include "summarizer.h"
 #include "textarea.h"
+#include "slider.h"
+#include "ppm.h"
 
 #include <unistd.h>
 
@@ -35,24 +46,29 @@
 #include <vector>
 #include <deque>
 #include <list>
+#include <map>
 #include <time.h>
 #include <fcntl.h>
 #include <errno.h>
 
 extern int   gHighscore;
 extern bool  gBounce;
-extern bool  gPaddle;
 extern bool  gResponseCode;
+extern bool  gDisableProgress;
 extern float gSplash;
+extern float gStartPosition;
+extern float gStopPosition;
 
 void logstalgia_help();
-void logstalgia_help(char* error);
+void logstalgia_info(std::string msg);
+void logstalgia_quit(std::string error);
+void logstalgia_help(std::string error);
 
 class Logstalgia : public SDLApp {
 
-    Paddle* paddle;
+    std::map<std::string,Paddle*> paddles;
 
-    int maxrows;
+    int buffer_row_count;
 
     std::string logfile;
 
@@ -63,11 +79,18 @@ class Logstalgia : public SDLApp {
     bool paused;
     bool recentre;
     bool next;
+    bool sync;
 
     long starttime;
     long currtime;
     long lasttime;
 
+    float screen_blank_interval;
+    float screen_blank_period;
+    float screen_blank_elapsed;
+
+    float font_alpha;
+
     float elapsed_time;
 
     float simu_speed;
@@ -83,36 +106,63 @@ class Logstalgia : public SDLApp {
     int remaining_space;
     int total_entries;
 
+    vec3f background;
+    vec4f paddle_colour;
+
     TextureResource* balltex;
+    TextureResource* glowtex;
 
     float mousehide_timeout;
     vec2f mousepos;
     RequestBall* paddle_target;
 
-    FontPack* fonts;
+    FXFont fontSmall;
+    FXFont fontMedium;
+    FXFont fontLarge;
+
     Summarizer* ipSummarizer;
 
     std::vector<Summarizer*> summGroups;
 
-    FILE* loghandle;
+    PositionSlider slider;
+
+    AccessLog* accesslog;
+
+    SeekLog* seeklog;
+    StreamLog* streamlog;
 
     std::deque<LogEntry> entries;
     std::list<RequestBall*> balls;
 
     TextArea infowindow;
 
+    float time_scale;
+
+    float runtime;
+    float fixed_tick_rate;
+    int framecount;
+    int frameskip;
+    FrameExporter* frameExporter;
+
+    std::string filterURLHostname(std::string hostname);
+
+    std::string dateAtPosition(float percent);
+    void seekTo(float percent);
+
     void readLog();
 
-    RequestBall* findNearest();
+    RequestBall* findNearest(Paddle* paddle, std::string paddle_proc);
     void updateGroups(float dt);
-    void drawGroups(float dt);
+    void drawGroups(float dt, float alpha);
 
     void addBall(LogEntry& le,  float head_start);
+    void removeBall(RequestBall* ball);
     void addGroup(std::string grouptitle, std::string groupregex, int percent = 0, vec3f colour = vec3f(0.0f, 0.0f, 0.0f));
     void togglePause();
 
-    void setMessage(std::string message);
+    BaseLog* getLog();
 
+    void reset();
 	void logic(float t, float dt);
 	void draw(float t, float dt);
 public:
@@ -121,6 +171,12 @@ public:
 
     void addGroup(std::string groupstr);
 
+    void setFrameExporter(FrameExporter* exporter, int video_framerate);
+
+    void syncLog();
+
+    void setBackground(vec3f background);
+
     //inherited methods
     void init();
     void update(float t, float dt);
@@ -129,5 +185,4 @@ public:
 	void mouseClick(SDL_MouseButtonEvent *e);
 };
 
-
 #endif
