@@ -18,7 +18,7 @@
 #ifndef REQUESTBALL_H
 #define REQUESTBALL_H
 
-#include "core/fontpack.h"
+#include "core/fxfont.h"
 
 #include "logentry.h"
 #include "ball.h"
@@ -33,7 +33,7 @@ protected:
     vec3f pagecolour;
     vec3f responseColour();
 
-    FPInstance font;
+    FXFont font;
 
     TextureResource* tex;
 
@@ -44,13 +44,22 @@ protected:
 public:
     LogEntry le;
 
-    RequestBall(LogEntry& le, FPInstance font, TextureResource* tex, vec3f colour, vec2f pos, vec2f dest, float speed = 10.0f);
+    RequestBall(LogEntry& le, FXFont font, TextureResource* tex, vec3f colour, vec2f pos, vec2f dest, float speed = 10.0f);
 
     ~RequestBall();
     bool mouseOver(TextArea& textarea, vec2f& mouse);
     void logic(float dt);
+
+    void drawGlow();
+
     void draw(float dt);
 
 };
 
+extern bool gDisableGlow;
+extern float gGlowIntensity;
+extern float gGlowMultiplier;
+extern float gGlowDuration;
+
+
 #endif
