@@ -315,11 +315,11 @@ void SummItem::updateUnit(SummUnit& unit) {
     }
 
     this->displaystr = std::string(buff);
-    this->width = font.width(displaystr.c_str());
+    this->width = font.getWidth(displaystr);
 
 }
 
-SummItem::SummItem(SummUnit unit, vec2f pos, vec2f dest, float target_x, vec3f* icol, FPInstance font, bool showcount) {
+SummItem::SummItem(SummUnit unit, vec2f pos, vec2f dest, float target_x, vec3f* icol, FXFont font, bool showcount) {
     this->pos  = pos;
     this->target_x = target_x;
     this->icol = icol;
@@ -376,14 +376,14 @@ void SummItem::logic(float dt) {
     }
 }
 
-void SummItem::draw() {
-    glColor4fv(colour);
+void SummItem::draw(float alpha) {
+    glColor4f(colour.x, colour.y, colour.z, colour.w * alpha);
     font.draw((int)pos.x, (int)pos.y, displaystr.c_str());
 }
 
 // Summarizer
 
-Summarizer::Summarizer(FPInstance font, float x, float top_gap, float bottom_gap, float refresh_delay, std::string matchstr, std::string title)
+Summarizer::Summarizer(FXFont font, float x, float top_gap, float bottom_gap, float refresh_delay, std::string matchstr, std::string title)
     : matchre(matchstr)
  {
     this->pos_x      = x;
@@ -399,7 +399,7 @@ Summarizer::Summarizer(FPInstance font, float x, float top_gap, float bottom_gap
     this->showcount=false;
 
 
-    font_gap    = font.getSize() + 4;
+    font_gap    = font.getHeight() + 4;
     max_strings = (int) ((display.height-top_gap-bottom_gap)/font_gap);
     incrementf   =0;
     root = SummNode();
@@ -431,7 +431,7 @@ bool Summarizer::mouseOver(TextArea& textarea, vec2f mouse) {
         SummItem* si = &(*it);
         if(si->departing) continue;
 
-        if(si->pos.y<=y && (si->pos.y+font.getSize()+4) > y) {
+        if(si->pos.y<=y && (si->pos.y+font.getHeight()+4) > y) {
             if(mouse.x< si->pos.x || mouse.x > si->pos.x + si->width) continue;
 
             std::vector<std::string> content;
@@ -594,7 +594,7 @@ std::string Summarizer::getBestMatchStr(std::string& str) {
 
 
 float Summarizer::getMiddlePosY(std::string& str) {
-    return getPosY(str) + font.getSize() / 2;
+    return getPosY(str) + (font.getHeight()) / 2;
 }
 
 float Summarizer::getPosY(std::string& str) {
@@ -641,19 +641,19 @@ void Summarizer::logic(float dt) {
     }
 }
 
-void Summarizer::draw(float dt) {
+void Summarizer::draw(float dt, float alpha) {
    	glEnable(GL_BLEND);
 	glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 	glEnable(GL_TEXTURE_2D);
 
     if(title.size()) {
-        glColor4f(1.0f, 1.0f, 1.0f, 1.0f);
+        glColor4f(1.0f, 1.0f, 1.0f, alpha);
         font.draw((int)pos_x, (int)(top_gap - font_gap), title.c_str());
     }
 
     std::list<SummItem>::iterator it;
     for(it=items.begin();it!=items.end();it++) {
-        (*it).draw();
+        (*it).draw(alpha);
     }
 
 }
